Cheetah Developer’s Guide — Cheetah3 - The Python-Powered Template Engine

# Cheetah Developer’s Guide

## Overview

This guide needs to really be filled out more

- Introduction
- The compiler
- The parser
- Directives: Error Handling
- Placeholders
- Patching Cheetah
- Directives: Flow Control
- Design Decisions and Tradeoffs
- Safe Delegation
- History of Cheetah
- Directives: Output
- Files
- Caching placeholders and #cache
- A BNF Grammar of Cheetah
- .py Template Modules
- Directives: Comments
- Directives: Parser Instructions
- Template
- Directives: Import, Inheritance, Declaration and Assignment